@@ -77,19 +77,21 @@ L<Filter::Crypto>, L<PAR::Filter::Crypto>
 
 Audrey Tang E<lt>cpan@audreyt.orgE<gt>
 
-L<http://par.perl.org/> is the official PAR website.  You can write
+You can write
 to the mailing list at E<lt>par@perl.orgE<gt>, or send an empty mail to
 E<lt>par-subscribe@perl.orgE<gt> to participate in the discussion.
+Archives of the mailing list are available at
+E<lt>https://www.mail-archive.com/par@perl.org/E<gt> or E<lt>https://groups.google.com/g/perl.parE<gt>.
 
-Please submit bug reports to E<lt>bug-par@rt.cpan.orgE<gt>.
+Please submit bug reports to E<lt>https://github.com/rschupp/PAR-Packer/issuesE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2003-2008 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
+Copyright 2003-2009 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
-See L<http://www.perl.com/perl/misc/Artistic.html>
+See F<LICENSE>.
 
 =cut
