@@ -22,6 +22,14 @@ by default.
 
 sub PATCH_CONTENT () { +{
     map { ref($_) ? $_ : lc($_) }
+    'AutoLoader.pm' => [
+        '$is_dosish = ' =>
+        '$is_dosish = $^O eq \'cygwin\' || ',
+    ],
+    'DynaLoader.pm' => [
+        'my $do_expand = ' =>                   # perl >= 5.36.0
+        'use vars qw($do_expand); $do_expand = ',
+    ],
     'Pod/Usage.pm' => [
         ' = $0' =>
         ' = $ENV{PAR_0} || $0',
@@ -75,7 +83,9 @@ sub PATCH_CONTENT () { +{
     ],
     'XSLoader.pm'     => [
         'goto retry unless $module and defined &dl_load_file;' =>
-        'goto retry;',
+            'goto retry;',                              # XSLoader <= 0.10
+        'goto \&XSLoader::bootstrap_inherit unless $module and defined &dl_load_file;' =>
+            'goto \&XSLoader::bootstrap_inherit;',      # XSLoader >= 0.14
     ],
     'diagnostics.pm'        => [
         'CONFIG: ' => 'CONFIG: if (0) ',
@@ -132,19 +142,21 @@ L<PAR::Filter>
 
 Audrey Tang E<lt>cpan@audreyt.orgE<gt>
 
-L<http://par.perl.org/> is the official PAR website.  You can write
+You can write
 to the mailing list at E<lt>par@perl.orgE<gt>, or send an empty mail to
 E<lt>par-subscribe@perl.orgE<gt> to participate in the discussion.
+Archives of the mailing list are available at
+E<lt>https://www.mail-archive.com/par@perl.org/E<gt> or E<lt>https://groups.google.com/g/perl.parE<gt>.
 
-Please submit bug reports to E<lt>bug-par@rt.cpan.orgE<gt>.
+Please submit bug reports to E<lt>https://github.com/rschupp/PAR-Packer/issuesE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2003, 2004, 2005, 2006, 2007, 2008 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
+Copyright 2003-2009 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
-See L<http://www.perl.com/perl/misc/Artistic.html>
+See F<LICENSE>.
 
 =cut
